/**************************************************
-------- EA TFT009-81AINN PIN DESCRIPTION --------
 1: SPI4W (connect to high for 4-Wire SPI, used in this sample project)
 2: NC
 3: SPI MOSI
 4: SPI SCL
 5: DC (Data = high / Command = low) selection pin
 6: Reset (low active)
 7: SPI CS
 8: GND
 9: NC
10: 3.3 V
11: LEDK
12: LEDA (please use a limiting resitor (around 4.7 Ohms or led driver)
13: GND
**************************************************/

#ifndef TFT80X160_H
#define TFT80X160_H
#ifdef __cplusplus
extern "C" {
#endif

typedef unsigned char BYTE;
typedef unsigned short WORD;
typedef unsigned long DWORD;

#define NULL (0L)

#define TFTWIDTH		80
#define TFTHEIGHT		160

#define LO(w)			( (w)     & 0xFF)
#define HI(w)			(((w)>>8) & 0xFF)
#define RGB565(r,g,b)	( (((WORD)(r)&0x00F8) << 8) | (((WORD)(g)&0x00FC) << 3) |  ((b)>>3) )

#define FONT_6X8 	1
#define FONT_7X12	2
#define FONT_8X16	3
#define FONT_30X38	4

//------------------------------------------------------------------------------
void TFTinit		(void); //Initialize TFT, external reset needed
void setTFTangle	(WORD angle); //Landscape (=90 or =270), Portrait(=0 or =90)

//Show characters:
void setTFTfont			(BYTE nr, BYTE zx, BYTE zy); //Font number (FONT_6X8 ...), Zoom in X and Zoom in Y
void setTFTcolor		(WORD fg, WORD bg); //fg = foregroundcolor, bg=backgroundcolor
void TFTtext		    (WORD xs, WORD ys, char *ptext); //print character string

//Drawing routines
void TFTfill	(WORD color, WORD xs, WORD ys, WORD xe, WORD ye); //Fill area

void TFTbitmap	(WORD xs, WORD ys, const BYTE *pbitmap); //show uncompressed bmp file

//------------------------------------------------------------------------------
// External functions needed 
//------------------------------------------------------------------------------
extern void write_cmd(BYTE dat); //SPI send one byte with Data-Command Line low
extern void write_dat(BYTE dat); //SPI send one byte with Data-Command Line high
extern void write_dat_buf(BYTE *dat, WORD len); //SPI send array with Data-Command Line high
extern void delay_ms(DWORD ms); //wait states (needed during initialisation

//------------------------------------------------------------------------------
// Globale Variables to read by the host system
//------------------------------------------------------------------------------
extern WORD gColorFG, gColorBG, gAngle, gTFTwidth, gTFTheight;

#ifdef __cplusplus
} // extern "C"
#endif
#endif  /* TFT80X160_H */
